Struct PortListenerLocalBuilder

pub struct PortListenerLocalBuilder<'a> { /* private fields */ }
A builder for registering port event callbacks.

Use Port::add_listener_local to create this and register callbacks that will be called when events of interest occur. After adding callbacks, use register to get back a PortListener.

Examples

let port_listener = port.add_listener_local()
    .info(|info| println!("New port info: {info:?}"))
    .param(|seq, param_type, index, next, param| {
        println!("New port param: seq {seq}, param type {param_type:?}, index {index}, next {next}, param {:?}",
            param.map(Pod::as_bytes));
    })
    .register();

Implementations

Source

impl<'a> PortListenerLocalBuilder<'a>

pub fn info<F>(self, info: F) -> Self
where F: Fn(&PortInfoRef) + 'static,

Set the port info event callback of the listener.

Callback parameters

info: Info about the port.

Examples
let port_listener = port.add_listener_local()
    .info(|info| println!("New port info: {info:?}"))
    .register();
pub fn param<F>(self, param: F) -> Self
where F: Fn(i32, ParamType, u32, u32, Option<&Pod>) + 'static,

Set the port param event callback of the listener.

This event is emitted as a result of enum_params or subscribe_params.

Callback parameters

seq: The sequence number of the request
param_type: The param type
index: The param index
next: The param index of the next param
param: The param

Examples
let port_listener = port.add_listener_local()
    .param(|seq, param_type, index, next, param| {
        println!("New port param: seq {seq}, param type {param_type:?}, index {index}, next {next}, param {:?}",
            param.map(Pod::as_bytes));
    })
    .register();
pub fn register(self) -> PortListener

Subscribe to events and register any provided callbacks.